@@ -3,13 +3,13 @@ package LUGS::Events::Parser::Event;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new
 {
     my $class = shift;
 
-    return bless { event => { @_ } }, ref($class) || $class;
+    return bless { event => { @_ } }, $class;
 }
 
 sub get_event_date
